@@ -8,7 +8,7 @@ class Migration(migrations.Migration):
 
     dependencies = [
         ('blog_extension', '0008_auto_20190522_0409'),
-        ('statistics', '0001_initial'),
+        ('stats', '0001_initial'),
     ]
 
     operations = [
